function [coeffs,fun] = acoustic_wave_2d(n1,z)
%ACOUSTIC_WAVE_2D   Acoustic wave problem in 2 dimensions.
%  [COEFFS,FUN] = NLEVP('acoustic_wave_2d',N1,Z) constructs a quadratic
%  matrix polynomial lambda^2*M + lambda*D + K that arises from
%  the discretization by finite elements of a two-dimensional acoustic
%  wave equation. The coefficient matrices are N-by-N with
%  N = N1*(N1-1), H  = 1/N1 being the mesh size.  The damping matrix has the
%  form 2*pi*i*Z^(-1)*C, where C is a low rank real symmetric matrix and
%  the scalar parameter Z is the impedance (possibly complex).
%  The default values are N1 = 6 (N = 30) and Z = 1.
%  The eigenvalues lie in the upper half of the complex plane.
%  The matrices are returned in a cell array: COEFFS = {K, D, M};
%  FUN is a function handle to evaluate the monomials 1,lambda,lambda^2
%  and their derivatives.
%  This problem has the properties pep, qep, symmetric, *-even
%  parameter-dependent, scalable.

%  Reference:
%  F. Chaitin-Chatelin and M. B. van Gijzen, Analysis of parameterized
%  quadratic eigenvalue problems in computational acoustics with homotopic
%  deviation theory, Numer. Linear Algebra Appl. 13 (2006), pp. 487-512

if nargin < 2 || isempty(z), z = 1; end;
if nargin < 1 || isempty(n1), n1 = 6; end;

h = 1/n1;
D = toeplitz([4,-1,zeros(1,n1-2)]); D(n1,n1) = 2;
T = diag(ones(n1-2,1),1)+diag(ones(n1-2,1),-1);
S = eye(n1); S(n1,n1) = 0.5;
E = zeros(n1); E(n1,n1) = 1;

M = h^2*kron(eye(n1-1),S);
C = (h/z)*kron(eye(n1-1),E);
K = kron(eye(n1-1),D) + kron(T,-S);

coeffs = {K, 2*pi*1i*C, -(2*pi)^2*M};

fun = @(lam) nlevp_monomials(lam,2);
